from django.conf import settings
from django.contrib import admin
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.urls import include, path, re_path

from arkindex.project.api_v1 import api
from arkindex.project.views import (
    CdnHome,
    FrontendView,
    OpenAPIDocsView,
    PonosAgentDetails,
    PonosAgentsState,
    PonosArtifactDownload,
    PonosSecretDetails,
    PonosTaskUpdate,
    PonosWorkflowDetails,
)

# Fallback to the dummy frontend view when CDN_ASSETS_URL is not set
frontend_view = FrontendView if settings.CDN_ASSETS_URL is None else CdnHome

urlpatterns = [
    path('api/v1/', include((api, 'api'), namespace='api')),
    path('api-docs/', OpenAPIDocsView.as_view(), name='openapi-docs'),
    # Override Ponos endpoints
    path('ponos/v1/secret/<path:name>', PonosSecretDetails.as_view(), name='secret-details'),
    path('ponos/v1/agents/', PonosAgentsState.as_view(), name='ponos-agents'),
    path('ponos/v1/agent/<uuid:pk>/', PonosAgentDetails.as_view(), name='ponos-agent-details'),
    path('ponos/v1/task/<uuid:pk>/', PonosTaskUpdate.as_view(), name='ponos-task-update'),
    path(
        'ponos/v1/task/<uuid:pk>/artifact/<path:path>',
        PonosArtifactDownload.as_view(),
        name='ponos-artifact-dl'
    ),
    path('ponos/v1/workflow/<uuid:pk>/', PonosWorkflowDetails.as_view(), name='ponos-workflow-details'),
    path('ponos/', include('ponos.urls')),
    path('admin/', admin.site.urls),
    path('rq/', include('django_rq.urls')),
    # Frontend URLs the backend needs with django.urls.reverse
    # Link sent via email for password resets
    path('user/reset/<uidb64>/<token>/', frontend_view.as_view(), name='password_reset_confirm'),
    # Redirection URL for successful OAuth2 flows
    path('process/credentials/', frontend_view.as_view(), name='credentials'),
]

if 'debug_toolbar' in settings.INSTALLED_APPS:
    import debug_toolbar
    urlpatterns = [
        path('__debug__/', include(debug_toolbar.urls)),
    ] + urlpatterns

if settings.DEBUG:
    # Serve static files in development—this is done by manage.py runserver, but not by Daphne in dev
    urlpatterns.extend(staticfiles_urlpatterns())

# Add index.html using CDN assets
# It's served as a full fallback on 404 to support loading specific frontend urls
if settings.CDN_ASSETS_URL is not None:
    urlpatterns.append(re_path(r'^.*$', CdnHome.as_view(), name="home"))
